package java.awt;

import java.awt.event.ContainerEvent;
import java.awt.event.ContainerListener;
import java.awt.event.KeyEvent;
import java.awt.peer.ContainerPeer;
import java.awt.peer.LightweightPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;

public abstract class Container extends Component {
   int ncomponents;
   Component[] component = new Component[4];
   LayoutManager layoutMgr;
   private LightweightDispatcher dispatcher;
   private Dimension maxSize;
   transient ContainerListener containerListener;
   private static final long serialVersionUID = 4613797578919906343L;
   private int containerSerializedDataVersion = 1;

   protected Container() {
   }

   public int getComponentCount() {
      return this.countComponents();
   }

   public int countComponents() {
      return this.ncomponents;
   }

   public Component getComponent(int var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      Component var2;
      try {
         if (var1 < 0 || var1 >= this.ncomponents) {
            throw new ArrayIndexOutOfBoundsException("No such child: " + var1);
         }

         var2 = this.component[var1];
      } catch (Throwable var6) {
         throw var6;
      }

      return var2;
   }

   public Component[] getComponents() {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      Component[] var1;
      try {
         Component[] var4 = new Component[this.ncomponents];
         System.arraycopy(this.component, 0, var4, 0, this.ncomponents);
         var1 = var4;
      } catch (Throwable var6) {
         throw var6;
      }

      return var1;
   }

   public Insets getInsets() {
      return this.insets();
   }

   public Insets insets() {
      if (super.peer != null && super.peer instanceof ContainerPeer) {
         ContainerPeer var1 = (ContainerPeer)super.peer;
         return var1.insets();
      } else {
         return new Insets(0, 0, 0, 0);
      }
   }

   public Component add(Component var1) {
      this.addImpl(var1, (Object)null, -1);
      return var1;
   }

   public Component add(String var1, Component var2) {
      this.addImpl(var2, var1, -1);
      return var2;
   }

   public Component add(Component var1, int var2) {
      this.addImpl(var1, (Object)null, var2);
      return var1;
   }

   public void add(Component var1, Object var2) {
      this.addImpl(var1, var2, -1);
   }

   public void add(Component var1, Object var2, int var3) {
      this.addImpl(var1, var2, var3);
   }

   protected void addImpl(Component var1, Object var2, int var3) {
      Object var4 = Component.LOCK;
      synchronized(var4){}

      try {
         if (var3 > this.ncomponents || var3 < 0 && var3 != -1) {
            throw new IllegalArgumentException("illegal component position");
         }

         if (var1 instanceof Container) {
            for(Container var6 = this; var6 != null; var6 = var6.parent) {
               if (var6 == var1) {
                  throw new IllegalArgumentException("adding container's parent to itself");
               }
            }
         }

         if (var1 instanceof Window) {
            throw new IllegalArgumentException("adding a window to a container");
         }

         if (var1.parent != null) {
            var1.parent.remove(var1);
         }

         if (this.ncomponents == this.component.length) {
            Component[] var9 = new Component[this.ncomponents * 2];
            System.arraycopy(this.component, 0, var9, 0, this.ncomponents);
            this.component = var9;
         }

         if (var3 != -1 && var3 != this.ncomponents) {
            System.arraycopy(this.component, var3, this.component, var3 + 1, this.ncomponents - var3);
            this.component[var3] = var1;
            ++this.ncomponents;
         } else {
            this.component[this.ncomponents++] = var1;
         }

         var1.parent = this;
         if (super.valid) {
            this.invalidate();
         }

         if (super.peer != null) {
            var1.addNotify();
         }

         if (this.layoutMgr != null) {
            if (this.layoutMgr instanceof LayoutManager2) {
               ((LayoutManager2)this.layoutMgr).addLayoutComponent(var1, var2);
            } else if (var2 instanceof String) {
               this.layoutMgr.addLayoutComponent((String)var2, var1);
            }
         }

         if (this.containerListener != null || (super.eventMask & 2L) != 0L) {
            ContainerEvent var10 = new ContainerEvent(this, 300, var1);
            this.processEvent(var10);
         }
      } catch (Throwable var8) {
         throw var8;
      }

   }

   public void remove(int var1) {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      try {
         Component var4 = this.component[var1];
         if (super.peer != null) {
            var4.removeNotify();
         }

         if (this.layoutMgr != null) {
            this.layoutMgr.removeLayoutComponent(var4);
         }

         var4.parent = null;
         System.arraycopy(this.component, var1 + 1, this.component, var1, this.ncomponents - var1 - 1);
         this.component[--this.ncomponents] = null;
         if (super.valid) {
            this.invalidate();
         }

         if (this.containerListener != null || (super.eventMask & 2L) != 0L) {
            ContainerEvent var5 = new ContainerEvent(this, 301, var4);
            this.processEvent(var5);
         }
      } catch (Throwable var7) {
         throw var7;
      }

   }

   public void remove(Component var1) {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      try {
         if (var1.parent == this) {
            int var4 = this.ncomponents;

            while(true) {
               --var4;
               if (var4 < 0) {
                  break;
               }

               if (this.component[var4] == var1) {
                  this.remove(var4);
               }
            }
         }
      } catch (Throwable var6) {
         throw var6;
      }

   }

   public void removeAll() {
      Object var1 = Component.LOCK;
      synchronized(var1){}

      try {
         while(this.ncomponents > 0) {
            Component var3 = this.component[--this.ncomponents];
            this.component[this.ncomponents] = null;
            if (super.peer != null) {
               var3.removeNotify();
            }

            if (this.layoutMgr != null) {
               this.layoutMgr.removeLayoutComponent(var3);
            }

            var3.parent = null;
            if (this.containerListener != null || (super.eventMask & 2L) != 0L) {
               ContainerEvent var4 = new ContainerEvent(this, 301, var3);
               this.processEvent(var4);
            }
         }

         if (super.valid) {
            this.invalidate();
         }
      } catch (Throwable var6) {
         throw var6;
      }

   }

   public LayoutManager getLayout() {
      return this.layoutMgr;
   }

   public void setLayout(LayoutManager var1) {
      this.layoutMgr = var1;
      if (super.valid) {
         this.invalidate();
      }

   }

   public void doLayout() {
      this.layout();
   }

   public void layout() {
      LayoutManager var1 = this.layoutMgr;
      if (var1 != null) {
         var1.layoutContainer(this);
      }

   }

   public void invalidate() {
      if (this.layoutMgr instanceof LayoutManager2) {
         LayoutManager2 var1 = (LayoutManager2)this.layoutMgr;
         var1.invalidateLayout(this);
      }

      super.invalidate();
   }

   public void validate() {
      if (!super.valid) {
         Object var1 = Component.LOCK;
         synchronized(var1){}

         try {
            if (!super.valid && super.peer != null) {
               ((Component)this).getCursor();
               ContainerPeer var3 = null;
               if (super.peer instanceof ContainerPeer) {
                  var3 = (ContainerPeer)super.peer;
               }

               if (var3 != null) {
                  var3.beginValidate();
               }

               this.validateTree();
               super.valid = true;
               if (var3 != null) {
                  var3.endValidate();
               }
            }
         } catch (Throwable var5) {
            throw var5;
         }

      }
   }

   protected void validateTree() {
      if (!super.valid) {
         this.doLayout();

         for(int var1 = 0; var1 < this.ncomponents; ++var1) {
            Component var2 = this.component[var1];
            if (var2 instanceof Container && !(var2 instanceof Window) && !var2.valid) {
               ((Container)var2).validateTree();
            } else {
               var2.valid = true;
            }
         }
      }

      super.valid = true;
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Dimension var1 = super.prefSize;
      if (var1 != null && ((Component)this).isValid()) {
         return var1;
      } else {
         Object var3 = Component.LOCK;
         synchronized(var3){}

         Dimension var2;
         try {
            super.prefSize = this.layoutMgr != null ? this.layoutMgr.preferredLayoutSize(this) : super.preferredSize();
            var2 = super.prefSize;
         } catch (Throwable var6) {
            throw var6;
         }

         return var2;
      }
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Dimension var1 = super.minSize;
      if (var1 != null && ((Component)this).isValid()) {
         return var1;
      } else {
         Object var3 = Component.LOCK;
         synchronized(var3){}

         Dimension var2;
         try {
            super.minSize = this.layoutMgr != null ? this.layoutMgr.minimumLayoutSize(this) : super.minimumSize();
            var2 = super.minSize;
         } catch (Throwable var6) {
            throw var6;
         }

         return var2;
      }
   }

   public Dimension getMaximumSize() {
      Dimension var1 = this.maxSize;
      if (var1 != null && ((Component)this).isValid()) {
         return var1;
      } else {
         if (this.layoutMgr instanceof LayoutManager2) {
            Object var2 = Component.LOCK;
            synchronized(var2){}

            try {
               LayoutManager2 var4 = (LayoutManager2)this.layoutMgr;
               this.maxSize = var4.maximumLayoutSize(this);
            } catch (Throwable var6) {
               throw var6;
            }
         } else {
            this.maxSize = super.getMaximumSize();
         }

         return this.maxSize;
      }
   }

   public float getAlignmentX() {
      float var1;
      if (this.layoutMgr instanceof LayoutManager2) {
         Object var2 = Component.LOCK;
         synchronized(var2){}

         try {
            LayoutManager2 var4 = (LayoutManager2)this.layoutMgr;
            var1 = var4.getLayoutAlignmentX(this);
         } catch (Throwable var6) {
            throw var6;
         }
      } else {
         var1 = super.getAlignmentX();
      }

      return var1;
   }

   public float getAlignmentY() {
      float var1;
      if (this.layoutMgr instanceof LayoutManager2) {
         Object var2 = Component.LOCK;
         synchronized(var2){}

         try {
            LayoutManager2 var4 = (LayoutManager2)this.layoutMgr;
            var1 = var4.getLayoutAlignmentY(this);
         } catch (Throwable var6) {
            throw var6;
         }
      } else {
         var1 = super.getAlignmentY();
      }

      return var1;
   }

   public void paint(Graphics var1) {
      if (((Component)this).isShowing()) {
         int var2 = this.ncomponents;
         Rectangle var3 = var1.getClipRect();

         for(int var4 = var2 - 1; var4 >= 0; --var4) {
            Component var5 = this.component[var4];
            if (var5 != null && var5.peer instanceof LightweightPeer && var5.visible) {
               Rectangle var6 = var5.getBounds();
               if (var3 == null || var6.intersects(var3)) {
                  Graphics var7 = var1.create(var6.x, var6.y, var6.width, var6.height);

                  try {
                     var5.paint(var7);
                  } finally {
                     var7.dispose();
                  }
               }
            }
         }
      }

   }

   public void print(Graphics var1) {
      super.print(var1);
      int var2 = this.ncomponents;
      Rectangle var3 = var1.getClipRect();

      for(int var4 = var2 - 1; var4 >= 0; --var4) {
         Component var5 = this.component[var4];
         if (var5 != null && var5.peer instanceof LightweightPeer) {
            Rectangle var6 = var5.getBounds();
            if (var6.intersects(var3)) {
               Graphics var7 = var1.create(var6.x, var6.y, var6.width, var6.height);

               try {
                  var5.print(var7);
               } finally {
                  var7.dispose();
               }
            }
         }
      }

   }

   public void paintComponents(Graphics var1) {
      int var2 = this.ncomponents;

      for(int var3 = var2 - 1; var3 >= 0; --var3) {
         Component var4 = this.component[var3];
         if (var4 != null) {
            Graphics var5 = var4.getGraphics();
            Rectangle var6 = var1.getClipRect();
            if (var6 != null) {
               Rectangle var7 = var4.getBounds();
               if (!var7.intersects(var6)) {
                  continue;
               }

               Rectangle var8 = var7.intersection(var6);
               var8.translate(-var7.x, -var7.y);
               var5.clipRect(var8.x, var8.y, var8.width, var8.height);
            }

            try {
               var4.paintAll(var5);
            } finally {
               var5.dispose();
            }
         }
      }

   }

   public void printComponents(Graphics var1) {
      int var2 = this.ncomponents;

      for(int var3 = 0; var3 < var2; ++var3) {
         Component var4 = this.component[var3];
         if (var4 != null) {
            Graphics var5 = var1.create(var4.x, var4.y, var4.width, var4.height);

            try {
               var4.printAll(var5);
            } finally {
               var5.dispose();
            }
         }
      }

   }

   public synchronized void addContainerListener(ContainerListener var1) {
      this.containerListener = AWTEventMulticaster.add(this.containerListener, var1);
      super.newEventsOnly = true;
   }

   public void removeContainerListener(ContainerListener var1) {
      this.containerListener = AWTEventMulticaster.remove(this.containerListener, var1);
   }

   boolean eventEnabled(AWTEvent var1) {
      int var2 = var1.getID();
      if (var2 != 300 && var2 != 301) {
         return super.eventEnabled(var1);
      } else {
         return (super.eventMask & 2L) != 0L || this.containerListener != null;
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ContainerEvent) {
         this.processContainerEvent((ContainerEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processContainerEvent(ContainerEvent var1) {
      if (this.containerListener != null) {
         switch (((AWTEvent)var1).getID()) {
            case 300:
               this.containerListener.componentAdded(var1);
               return;
            case 301:
               this.containerListener.componentRemoved(var1);
               return;
         }
      }

   }

   void dispatchEventImpl(AWTEvent var1) {
      if (this.dispatcher != null && this.dispatcher.dispatchEvent(var1)) {
         var1.consume();
         if (super.peer != null) {
            super.peer.handleEvent(var1);
         }

      } else {
         super.dispatchEventImpl(var1);
      }
   }

   Component getMouseEventTarget(int var1, int var2) {
      int var3 = this.ncomponents;

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = this.component[var4];
         if (var5 != null && var5.contains(var1 - var5.x, var2 - var5.y) && var5.peer instanceof LightweightPeer && var5.visible) {
            if (var5 instanceof Container) {
               Container var6 = (Container)var5;
               Component var7 = var6.getMouseEventTarget(var1 - var6.x, var2 - var6.y);
               if (var7 != null) {
                  return var7;
               }
            } else if (var5.mouseListener != null || (var5.eventMask & 16L) != 0L || var5.mouseMotionListener != null || (var5.eventMask & 32L) != 0L) {
               return var5;
            }
         }
      }

      if ((super.mouseListener != null || (super.eventMask & 16L) != 0L || super.mouseMotionListener != null || (super.eventMask & 32L) != 0L) && super.peer instanceof LightweightPeer) {
         return this;
      } else {
         return null;
      }
   }

   void proxyEnableEvents(long var1) {
      if (super.peer instanceof LightweightPeer) {
         super.parent.proxyEnableEvents(var1);
      } else {
         if (this.dispatcher != null) {
            this.dispatcher.enableEvents(var1);
         }

      }
   }

   Window getWindow() {
      Container var1;
      for(var1 = this; !(var1 instanceof Window); var1 = ((Component)var1).getParent()) {
      }

      return (Window)var1;
   }

   void proxyRequestFocus(Component var1) {
      if (super.peer instanceof LightweightPeer) {
         super.parent.proxyRequestFocus(var1);
      } else {
         if (this.dispatcher.setFocusRequest(var1)) {
            super.peer.requestFocus();
            Toolkit.getEventQueue().changeKeyEventFocus(this);
         }

      }
   }

   public void deliverEvent(Event var1) {
      Component var2 = this.getComponentAt(var1.x, var1.y);
      if (var2 != null && var2 != this) {
         var1.translate(-var2.x, -var2.y);
         var2.deliverEvent(var1);
      } else {
         ((Component)this).postEvent(var1);
      }
   }

   public Component getComponentAt(int var1, int var2) {
      return this.locate(var1, var2);
   }

   public Component locate(int var1, int var2) {
      if (!((Component)this).contains(var1, var2)) {
         return null;
      } else {
         int var3 = this.ncomponents;

         for(int var4 = 0; var4 < var3; ++var4) {
            Component var5 = this.component[var4];
            if (var5 != null && var5.contains(var1 - var5.x, var2 - var5.y)) {
               return var5;
            }
         }

         return this;
      }
   }

   public Component getComponentAt(Point var1) {
      return this.getComponentAt(var1.x, var1.y);
   }

   public void addNotify() {
      super.addNotify();
      if (!(super.peer instanceof LightweightPeer)) {
         this.dispatcher = new LightweightDispatcher(this);
      }

      int var1 = this.ncomponents;

      for(int var2 = 0; var2 < var1; ++var2) {
         this.component[var2].addNotify();
      }

   }

   public void removeNotify() {
      int var1 = this.ncomponents;

      for(int var2 = 0; var2 < var1; ++var2) {
         this.component[var2].removeNotify();
      }

      super.removeNotify();
   }

   public boolean isAncestorOf(Component var1) {
      Container var2;
      if (var1 != null && (var2 = var1.getParent()) != null) {
         while(var2 != null) {
            if (var2 == this) {
               return true;
            }

            var2 = ((Component)var2).getParent();
         }

         return false;
      } else {
         return false;
      }
   }

   protected String paramString() {
      String var1 = super.paramString();
      LayoutManager var2 = this.layoutMgr;
      if (var2 != null) {
         var1 = var1 + ",layout=" + var2.getClass().getName();
      }

      return var1;
   }

   public void list(PrintStream var1, int var2) {
      super.list(var1, var2);
      int var3 = this.ncomponents;

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = this.component[var4];
         if (var5 != null) {
            var5.list(var1, var2 + 1);
         }
      }

   }

   public void list(PrintWriter var1, int var2) {
      super.list(var1, var2);
      int var3 = this.ncomponents;

      for(int var4 = 0; var4 < var3; ++var4) {
         Component var5 = this.component[var4];
         if (var5 != null) {
            var5.list(var1, var2 + 1);
         }
      }

   }

   void setFocusOwner(Component var1) {
      Container var2 = super.parent;
      if (var2 != null) {
         var2.setFocusOwner(var1);
      }

   }

   void preProcessKeyEvent(KeyEvent var1) {
      Container var2 = super.parent;
      if (var2 != null) {
         var2.preProcessKeyEvent(var1);
      }

   }

   void postProcessKeyEvent(KeyEvent var1) {
      Container var2 = super.parent;
      if (var2 != null) {
         var2.postProcessKeyEvent(var1);
      }

   }

   void transferFocus(Component var1) {
      this.nextFocus(var1);
   }

   boolean postsOldMouseEvents() {
      return true;
   }

   void nextFocus(Component var1) {
      Container var2 = super.parent;
      if (var2 != null) {
         var2.transferFocus(var1);
      }

   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "containerL", this.containerListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      for(int var2 = 0; var2 < this.ncomponents; ++var2) {
         this.component[var2].parent = this;
      }

      Object var3;
      while((var3 = var1.readObject()) != null) {
         String var4 = ((String)var3).intern();
         if (var4 == "containerL") {
            this.addContainerListener((ContainerListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }
}
