package java.awt;

import java.io.Serializable;

class FocusManager implements Serializable {
   Container focusRoot;
   Component focusOwner;

   FocusManager(Container var1) {
      this.focusRoot = var1;
   }

   void activateFocus() {
      boolean var1 = false;
      if (this.focusOwner != null) {
         if (!(var1 = this.assignFocus(this.focusOwner, false))) {
            var1 = this.focusNext(this.focusOwner);
         }
      } else {
         var1 = this.focusForward(this.focusRoot);
      }

      if (!var1) {
         this.focusRoot.requestFocus();
      }

   }

   void setFocusOwner(Component var1) {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      try {
         this.focusOwner = var1;
      } catch (Throwable var4) {
         throw var4;
      }

   }

   Component getFocusOwner() {
      return this.focusOwner;
   }

   boolean focusNext() {
      return this.focusNext(this.focusOwner);
   }

   boolean focusNext(Component var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      boolean var13;
      try {
         Object var5 = var1;
         if (var1 == null || var1.parent == null) {
            var13 = false;
            return var13;
         }

         Container var7;
         do {
            boolean var6 = false;
            var7 = ((Component)var5).parent;

            for(int var9 = 0; var9 < var7.ncomponents; ++var9) {
               Component var8 = var7.component[var9];
               if (var6) {
                  if (this.assignFocus(var8)) {
                     var13 = true;
                     return var13;
                  }

                  if (var8 instanceof Container && var8.isVisible() && var8.isEnabled() && this.focusForward((Container)var8)) {
                     var13 = true;
                     return var13;
                  }
               } else if (var8 == var5) {
                  var6 = true;
               }
            }

            var5 = var7;
         } while(var7 != this.focusRoot);

         if (!this.focusForward(this.focusRoot)) {
            var13 = false;
            return var13;
         }

         var13 = true;
      } catch (Throwable var11) {
         throw var11;
      }

      return var13;
   }

   boolean focusPrevious() {
      return this.focusPrevious(this.focusOwner);
   }

   boolean focusPrevious(Component var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      boolean var13;
      try {
         Object var5 = var1;
         if (var1 == null || var1.parent == null) {
            var13 = false;
            return var13;
         }

         Container var7;
         do {
            boolean var6 = false;
            var7 = ((Component)var5).parent;

            for(int var9 = var7.ncomponents - 1; var9 >= 0; --var9) {
               Component var8 = var7.component[var9];
               if (var6) {
                  if (this.assignFocus(var8)) {
                     var13 = true;
                     return var13;
                  }

                  if (var8 instanceof Container && var8.isVisible() && var8.isEnabled() && this.focusBackward((Container)var8)) {
                     var13 = true;
                     return var13;
                  }
               } else if (var8 == var5) {
                  var6 = true;
               }
            }

            var5 = var7;
         } while(var7 != this.focusRoot);

         if (!this.focusBackward(this.focusRoot)) {
            var13 = false;
            return var13;
         }

         var13 = true;
      } catch (Throwable var11) {
         throw var11;
      }

      return var13;
   }

   boolean assignFocus(Component var1) {
      return this.assignFocus(var1, true);
   }

   boolean assignFocus(Component var1, boolean var2) {
      Object var4 = Component.LOCK;
      synchronized(var4){}

      boolean var3;
      try {
         if (!var1.isVisible() || !var1.isEnabled() || var2 && !var1.isFocusTraversable()) {
            var3 = false;
            return var3;
         }

         var1.requestFocus();
         var3 = true;
      } catch (Throwable var7) {
         throw var7;
      }

      return var3;
   }

   boolean focusForward(Container var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      try {
         for(int var5 = 0; var5 < var1.ncomponents; ++var5) {
            Component var6 = var1.component[var5];
            if (this.assignFocus(var6)) {
               boolean var9 = true;
               return var9;
            }

            if (var6 instanceof Container && var6.isVisible() && var6.isEnabled() && this.focusForward((Container)var6)) {
               boolean var2 = true;
               return var2;
            }
         }

         boolean var10 = false;
         return var10;
      } catch (Throwable var8) {
         throw var8;
      }
   }

   boolean focusBackward(Container var1) {
      Object var3 = Component.LOCK;
      synchronized(var3){}

      try {
         for(int var5 = var1.ncomponents - 1; var5 >= 0; --var5) {
            Component var6 = var1.component[var5];
            if (this.assignFocus(var6)) {
               boolean var9 = true;
               return var9;
            }

            if (var6 instanceof Container && var6.isVisible() && var6.isEnabled() && this.focusBackward((Container)var6)) {
               boolean var2 = true;
               return var2;
            }
         }

         boolean var10 = false;
         return var10;
      } catch (Throwable var8) {
         throw var8;
      }
   }
}
