package java.awt;

import java.io.Serializable;
import java.util.Hashtable;

public class GridBagLayout implements LayoutManager2, Serializable {
   protected static final int MAXGRIDSIZE = 512;
   protected static final int MINSIZE = 1;
   protected static final int PREFERREDSIZE = 2;
   protected Hashtable comptable = new Hashtable();
   protected GridBagConstraints defaultConstraints = new GridBagConstraints();
   protected GridBagLayoutInfo layoutInfo;
   public int[] columnWidths;
   public int[] rowHeights;
   public double[] columnWeights;
   public double[] rowWeights;

   public void setConstraints(Component var1, GridBagConstraints var2) {
      this.comptable.put(var1, var2.clone());
   }

   public GridBagConstraints getConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return (GridBagConstraints)var2.clone();
   }

   protected GridBagConstraints lookupConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return var2;
   }

   public Point getLayoutOrigin() {
      Point var1 = new Point(0, 0);
      if (this.layoutInfo != null) {
         var1.x = this.layoutInfo.startx;
         var1.y = this.layoutInfo.starty;
      }

      return var1;
   }

   public int[][] getLayoutDimensions() {
      if (this.layoutInfo == null) {
         return new int[2][0];
      } else {
         int[][] var1 = new int[][]{new int[this.layoutInfo.width], new int[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.minWidth, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.minHeight, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public double[][] getLayoutWeights() {
      if (this.layoutInfo == null) {
         return new double[2][0];
      } else {
         double[][] var1 = new double[][]{new double[this.layoutInfo.width], new double[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.weightX, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.weightY, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public Point location(int var1, int var2) {
      Point var3 = new Point(0, 0);
      if (this.layoutInfo == null) {
         return var3;
      } else {
         int var5 = this.layoutInfo.startx;

         int var4;
         for(var4 = 0; var4 < this.layoutInfo.width; ++var4) {
            var5 += this.layoutInfo.minWidth[var4];
            if (var5 > var1) {
               break;
            }
         }

         var3.x = var4;
         var5 = this.layoutInfo.starty;

         for(var4 = 0; var4 < this.layoutInfo.height; ++var4) {
            var5 += this.layoutInfo.minHeight[var4];
            if (var5 > var2) {
               break;
            }
         }

         var3.y = var4;
         return var3;
      }
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void addLayoutComponent(Component var1, Object var2) {
      if (var2 instanceof GridBagConstraints) {
         this.setConstraints(var1, (GridBagConstraints)var2);
      } else if (var2 != null) {
         throw new IllegalArgumentException("cannot add to layout: constraint must be a GridBagConstraint");
      }
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 2);
      return this.GetMinSize(var1, var2);
   }

   public Dimension minimumLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 1);
      return this.GetMinSize(var1, var2);
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      this.ArrangeGrid(var1);
   }

   public String toString() {
      return this.getClass().getName();
   }

   protected GridBagLayoutInfo GetLayoutInfo(Container var1, int var2) {
      GridBagLayoutInfo var3 = new GridBagLayoutInfo();
      Component[] var7 = var1.getComponents();
      var3.width = var3.height = 0;
      int var20 = -1;
      int var19 = -1;
      int[] var25 = new int[512];
      int[] var26 = new int[512];

      for(int var8 = 0; var8 < var7.length; ++var8) {
         Component var4 = var7[var8];
         if (var4.isVisible()) {
            GridBagConstraints var5 = this.lookupConstraints(var4);
            int var15 = var5.gridx;
            int var16 = var5.gridy;
            int var17 = var5.gridwidth;
            if (var17 <= 0) {
               var17 = 1;
            }

            int var18 = var5.gridheight;
            if (var18 <= 0) {
               var18 = 1;
            }

            if (var15 < 0 && var16 < 0) {
               if (var19 >= 0) {
                  var16 = var19;
               } else if (var20 >= 0) {
                  var15 = var20;
               } else {
                  var16 = 0;
               }
            }

            if (var15 < 0) {
               int var11 = 0;

               for(int var9 = var16; var9 < var16 + var18; ++var9) {
                  var11 = Math.max(var11, var25[var9]);
               }

               var15 = var11 - var15 - 1;
               if (var15 < 0) {
                  var15 = 0;
               }
            } else if (var16 < 0) {
               int var12 = 0;

               for(int var37 = var15; var37 < var15 + var17; ++var37) {
                  var12 = Math.max(var12, var26[var37]);
               }

               var16 = var12 - var16 - 1;
               if (var16 < 0) {
                  var16 = 0;
               }
            }

            int var56;
            for(var56 = var15 + var17; var3.width < var56; ++var3.width) {
            }

            int var60;
            for(var60 = var16 + var18; var3.height < var60; ++var3.height) {
            }

            for(int var38 = var15; var38 < var15 + var17; ++var38) {
               var26[var38] = var60;
            }

            for(int var39 = var16; var39 < var16 + var18; ++var39) {
               var25[var39] = var56;
            }

            Dimension var6;
            if (var2 == 2) {
               var6 = var4.getPreferredSize();
            } else {
               var6 = var4.getMinimumSize();
            }

            var5.minWidth = var6.width;
            var5.minHeight = var6.height;
            if (var5.gridheight == 0 && var5.gridwidth == 0) {
               var20 = -1;
               var19 = -1;
            }

            if (var5.gridheight == 0 && var19 < 0) {
               var20 = var15 + var17;
            } else if (var5.gridwidth == 0 && var20 < 0) {
               var19 = var16 + var18;
            }
         }
      }

      if (this.columnWidths != null && var3.width < this.columnWidths.length) {
         var3.width = this.columnWidths.length;
      }

      if (this.rowHeights != null && var3.height < this.rowHeights.length) {
         var3.height = this.rowHeights.length;
      }

      var20 = -1;
      var19 = -1;
      var25 = new int[512];
      var26 = new int[512];

      for(int var35 = 0; var35 < var7.length; ++var35) {
         Component var31 = var7[var35];
         if (var31.isVisible()) {
            GridBagConstraints var33 = this.lookupConstraints(var31);
            int var65 = var33.gridx;
            int var66 = var33.gridy;
            int var67 = var33.gridwidth;
            int var68 = var33.gridheight;
            if (var65 < 0 && var66 < 0) {
               if (var19 >= 0) {
                  var66 = var19;
               } else if (var20 >= 0) {
                  var65 = var20;
               } else {
                  var66 = 0;
               }
            }

            if (var65 < 0) {
               if (var68 <= 0) {
                  var68 += var3.height - var66;
                  if (var68 < 1) {
                     var68 = 1;
                  }
               }

               int var57 = 0;

               for(int var40 = var66; var40 < var66 + var68; ++var40) {
                  var57 = Math.max(var57, var25[var40]);
               }

               var65 = var57 - var65 - 1;
               if (var65 < 0) {
                  var65 = 0;
               }
            } else if (var66 < 0) {
               if (var67 <= 0) {
                  var67 += var3.width - var65;
                  if (var67 < 1) {
                     var67 = 1;
                  }
               }

               int var61 = 0;

               for(int var41 = var65; var41 < var65 + var67; ++var41) {
                  var61 = Math.max(var61, var26[var41]);
               }

               var66 = var61 - var66 - 1;
               if (var66 < 0) {
                  var66 = 0;
               }
            }

            if (var67 <= 0) {
               var67 += var3.width - var65;
               if (var67 < 1) {
                  var67 = 1;
               }
            }

            if (var68 <= 0) {
               var68 += var3.height - var66;
               if (var68 < 1) {
                  var68 = 1;
               }
            }

            int var58 = var65 + var67;
            int var62 = var66 + var68;

            for(int var42 = var65; var42 < var65 + var67; ++var42) {
               var26[var42] = var62;
            }

            for(int var43 = var66; var43 < var66 + var68; ++var43) {
               var25[var43] = var58;
            }

            if (var33.gridheight == 0 && var33.gridwidth == 0) {
               var20 = -1;
               var19 = -1;
            }

            if (var33.gridheight == 0 && var19 < 0) {
               var20 = var65 + var67;
            } else if (var33.gridwidth == 0 && var20 < 0) {
               var19 = var66 + var68;
            }

            var33.tempX = var65;
            var33.tempY = var66;
            var33.tempWidth = var67;
            var33.tempHeight = var68;
         }
      }

      if (this.columnWidths != null) {
         System.arraycopy(this.columnWidths, 0, var3.minWidth, 0, this.columnWidths.length);
      }

      if (this.rowHeights != null) {
         System.arraycopy(this.rowHeights, 0, var3.minHeight, 0, this.rowHeights.length);
      }

      if (this.columnWeights != null) {
         System.arraycopy(this.columnWeights, 0, var3.weightX, 0, this.columnWeights.length);
      }

      if (this.rowWeights != null) {
         System.arraycopy(this.rowWeights, 0, var3.weightY, 0, this.rowWeights.length);
      }

      int var14 = Integer.MAX_VALUE;

      for(int var44 = 1; var44 != Integer.MAX_VALUE; var14 = Integer.MAX_VALUE) {
         for(int var36 = 0; var36 < var7.length; ++var36) {
            Component var32 = var7[var36];
            if (var32.isVisible()) {
               GridBagConstraints var34 = this.lookupConstraints(var32);
               if (var34.tempWidth == var44) {
                  int var59 = var34.tempX + var34.tempWidth;
                  double var21 = var34.weightx;

                  for(int var10 = var34.tempX; var10 < var59; ++var10) {
                     var21 -= var3.weightX[var10];
                  }

                  if (var21 > (double)0.0F) {
                     double var23 = (double)0.0F;

                     for(int var45 = var34.tempX; var45 < var59; ++var45) {
                        var23 += var3.weightX[var45];
                     }

                     for(int var46 = var34.tempX; var23 > (double)0.0F && var46 < var59; ++var46) {
                        double var27 = var3.weightX[var46];
                        double var29 = var27 * var21 / var23;
                        double[] var10000 = var3.weightX;
                        var10000[var46] += var29;
                        var21 -= var29;
                        var23 -= var27;
                     }

                     double[] var83 = var3.weightX;
                     var83[var59 - 1] += var21;
                  }

                  int var13 = var34.minWidth + var34.ipadx + var34.insets.left + var34.insets.right;

                  for(int var47 = var34.tempX; var47 < var59; ++var47) {
                     var13 -= var3.minWidth[var47];
                  }

                  if (var13 > 0) {
                     double var72 = (double)0.0F;

                     for(int var48 = var34.tempX; var48 < var59; ++var48) {
                        var72 += var3.weightX[var48];
                     }

                     for(int var49 = var34.tempX; var72 > (double)0.0F && var49 < var59; ++var49) {
                        double var77 = var3.weightX[var49];
                        int var80 = (int)(var77 * (double)var13 / var72);
                        int[] var84 = var3.minWidth;
                        var84[var49] += var80;
                        var13 -= var80;
                        var72 -= var77;
                     }

                     int[] var85 = var3.minWidth;
                     var85[var59 - 1] += var13;
                  }
               } else if (var34.tempWidth > var44 && var34.tempWidth < var14) {
                  var14 = var34.tempWidth;
               }

               if (var34.tempHeight != var44) {
                  if (var34.tempHeight > var44 && var34.tempHeight < var14) {
                     var14 = var34.tempHeight;
                  }
               } else {
                  int var63 = var34.tempY + var34.tempHeight;
                  double var71 = var34.weighty;

                  for(int var50 = var34.tempY; var50 < var63; ++var50) {
                     var71 -= var3.weightY[var50];
                  }

                  if (var71 > (double)0.0F) {
                     double var73 = (double)0.0F;

                     for(int var51 = var34.tempY; var51 < var63; ++var51) {
                        var73 += var3.weightY[var51];
                     }

                     for(int var52 = var34.tempY; var73 > (double)0.0F && var52 < var63; ++var52) {
                        double var78 = var3.weightY[var52];
                        double var81 = var78 * var71 / var73;
                        double[] var86 = var3.weightY;
                        var86[var52] += var81;
                        var71 -= var81;
                        var73 -= var78;
                     }

                     double[] var87 = var3.weightY;
                     var87[var63 - 1] += var71;
                  }

                  int var64 = var34.minHeight + var34.ipady + var34.insets.top + var34.insets.bottom;

                  for(int var53 = var34.tempY; var53 < var63; ++var53) {
                     var64 -= var3.minHeight[var53];
                  }

                  if (var64 > 0) {
                     double var74 = (double)0.0F;

                     for(int var54 = var34.tempY; var54 < var63; ++var54) {
                        var74 += var3.weightY[var54];
                     }

                     for(int var55 = var34.tempY; var74 > (double)0.0F && var55 < var63; ++var55) {
                        double var79 = var3.weightY[var55];
                        int var82 = (int)(var79 * (double)var64 / var74);
                        int[] var88 = var3.minHeight;
                        var88[var55] += var82;
                        var64 -= var82;
                        var74 -= var79;
                     }

                     int[] var89 = var3.minHeight;
                     var89[var63 - 1] += var64;
                  }
               }
            }
         }

         var44 = var14;
      }

      return var3;
   }

   protected void AdjustForGravity(GridBagConstraints var1, Rectangle var2) {
      var2.x += var1.insets.left;
      var2.width -= var1.insets.left + var1.insets.right;
      var2.y += var1.insets.top;
      var2.height -= var1.insets.top + var1.insets.bottom;
      int var3 = 0;
      if (var1.fill != 2 && var1.fill != 1 && var2.width > var1.minWidth + var1.ipadx) {
         var3 = var2.width - (var1.minWidth + var1.ipadx);
         var2.width = var1.minWidth + var1.ipadx;
      }

      int var4 = 0;
      if (var1.fill != 3 && var1.fill != 1 && var2.height > var1.minHeight + var1.ipady) {
         var4 = var2.height - (var1.minHeight + var1.ipady);
         var2.height = var1.minHeight + var1.ipady;
      }

      switch (var1.anchor) {
         case 10:
            var2.x += var3 / 2;
            var2.y += var4 / 2;
            return;
         case 11:
            var2.x += var3 / 2;
            return;
         case 12:
            var2.x += var3;
            return;
         case 13:
            var2.x += var3;
            var2.y += var4 / 2;
            return;
         case 14:
            var2.x += var3;
            var2.y += var4;
            return;
         case 15:
            var2.x += var3 / 2;
            var2.y += var4;
            return;
         case 16:
            var2.y += var4;
            return;
         case 17:
            var2.y += var4 / 2;
            return;
         case 18:
            return;
         default:
            throw new IllegalArgumentException("illegal anchor value");
      }
   }

   protected Dimension GetMinSize(Container var1, GridBagLayoutInfo var2) {
      Dimension var3 = new Dimension();
      Insets var6 = var1.getInsets();
      int var5 = 0;

      for(int var4 = 0; var4 < var2.width; ++var4) {
         var5 += var2.minWidth[var4];
      }

      var3.width = var5 + var6.left + var6.right;
      var5 = 0;

      for(int var7 = 0; var7 < var2.height; ++var7) {
         var5 += var2.minHeight[var7];
      }

      var3.height = var5 + var6.top + var6.bottom;
      return var3;
   }

   protected void ArrangeGrid(Container var1) {
      Insets var5 = var1.getInsets();
      Component[] var6 = var1.getComponents();
      Rectangle var8 = new Rectangle();
      if (var6.length != 0 || this.columnWidths != null && this.columnWidths.length != 0 || this.rowHeights != null && this.rowHeights.length != 0) {
         GridBagLayoutInfo var14 = this.GetLayoutInfo(var1, 2);
         Dimension var7 = this.GetMinSize(var1, var14);
         if (var1.width < var7.width || var1.height < var7.height) {
            var14 = this.GetLayoutInfo(var1, 1);
            var7 = this.GetMinSize(var1, var14);
         }

         this.layoutInfo = var14;
         var8.width = var7.width;
         var8.height = var7.height;
         int var10 = var1.width - var8.width;
         if (var10 != 0) {
            double var12 = (double)0.0F;

            for(int var9 = 0; var9 < var14.width; ++var9) {
               var12 += var14.weightX[var9];
            }

            if (var12 > (double)0.0F) {
               for(int var16 = 0; var16 < var14.width; ++var16) {
                  int var15 = (int)((double)var10 * var14.weightX[var16] / var12);
                  int[] var10000 = var14.minWidth;
                  var10000[var16] += var15;
                  var8.width += var15;
                  if (var14.minWidth[var16] < 0) {
                     var8.width -= var14.minWidth[var16];
                     var14.minWidth[var16] = 0;
                  }
               }
            }

            var10 = var1.width - var8.width;
         } else {
            var10 = 0;
         }

         int var11 = var1.height - var8.height;
         if (var11 != 0) {
            double var25 = (double)0.0F;

            for(int var17 = 0; var17 < var14.height; ++var17) {
               var25 += var14.weightY[var17];
            }

            if (var25 > (double)0.0F) {
               for(int var18 = 0; var18 < var14.height; ++var18) {
                  int var26 = (int)((double)var11 * var14.weightY[var18] / var25);
                  int[] var27 = var14.minHeight;
                  var27[var18] += var26;
                  var8.height += var26;
                  if (var14.minHeight[var18] < 0) {
                     var8.height -= var14.minHeight[var18];
                     var14.minHeight[var18] = 0;
                  }
               }
            }

            var11 = var1.height - var8.height;
         } else {
            var11 = 0;
         }

         var14.startx = var10 / 2 + var5.left;
         var14.starty = var11 / 2 + var5.top;

         for(int var3 = 0; var3 < var6.length; ++var3) {
            Component var2 = var6[var3];
            if (var2.isVisible()) {
               GridBagConstraints var4 = this.lookupConstraints(var2);
               var8.x = var14.startx;

               for(int var19 = 0; var19 < var4.tempX; ++var19) {
                  var8.x += var14.minWidth[var19];
               }

               var8.y = var14.starty;

               for(int var20 = 0; var20 < var4.tempY; ++var20) {
                  var8.y += var14.minHeight[var20];
               }

               var8.width = 0;

               for(int var21 = var4.tempX; var21 < var4.tempX + var4.tempWidth; ++var21) {
                  var8.width += var14.minWidth[var21];
               }

               var8.height = 0;

               for(int var22 = var4.tempY; var22 < var4.tempY + var4.tempHeight; ++var22) {
                  var8.height += var14.minHeight[var22];
               }

               this.AdjustForGravity(var4, var8);
               if (var8.width > 0 && var8.height > 0) {
                  if (var2.x != var8.x || var2.y != var8.y || var2.width != var8.width || var2.height != var8.height) {
                     var2.setBounds(var8.x, var8.y, var8.width, var8.height);
                  }
               } else {
                  var2.setBounds(0, 0, 0, 0);
               }
            }
         }

      }
   }
}
