package java.awt;

import java.awt.event.KeyEvent;
import java.awt.peer.MenuPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Enumeration;
import java.util.Vector;

public class Menu extends MenuItem implements MenuContainer {
   Vector items;
   boolean tearOff;
   boolean isHelpMenu;
   private static final String base = "menu";
   private static int nameCounter;
   private static final long serialVersionUID = -8809584163345499784L;
   private int menuSerializedDataVersion;

   public Menu() {
      this("", false);
   }

   public Menu(String var1) {
      this(var1, false);
   }

   public Menu(String var1, boolean var2) {
      super(var1);
      this.items = new Vector();
      this.menuSerializedDataVersion = 1;
      super.name = "menu" + nameCounter++;
      this.tearOff = var2;
   }

   public void addNotify() {
      if (super.peer == null) {
         super.peer = Toolkit.getDefaultToolkit().createMenu(this);
      }

      int var1 = this.getItemCount();

      for(int var2 = 0; var2 < var1; ++var2) {
         MenuItem var3 = this.getItem(var2);
         var3.parent = this;
         var3.addNotify();
      }

   }

   public void removeNotify() {
      int var1 = this.getItemCount();

      for(int var2 = 0; var2 < var1; ++var2) {
         this.getItem(var2).removeNotify();
      }

      super.removeNotify();
   }

   public boolean isTearOff() {
      return this.tearOff;
   }

   public int getItemCount() {
      return this.countItems();
   }

   public int countItems() {
      return this.items.size();
   }

   public MenuItem getItem(int var1) {
      return (MenuItem)this.items.elementAt(var1);
   }

   public synchronized MenuItem add(MenuItem var1) {
      if (var1.parent != null) {
         var1.parent.remove(var1);
      }

      this.items.addElement(var1);
      var1.parent = this;
      MenuPeer var2 = (MenuPeer)super.peer;
      if (var2 != null) {
         var1.addNotify();
         var2.addItem(var1);
      }

      return var1;
   }

   public void add(String var1) {
      this.add(new MenuItem(var1));
   }

   public synchronized void insert(MenuItem var1, int var2) {
      if (var2 < 0) {
         throw new IllegalArgumentException("index less than zero.");
      } else {
         int var3 = this.getItemCount();
         Vector var4 = new Vector();

         for(int var5 = var2; var5 < var3; ++var5) {
            var4.addElement(this.getItem(var2));
            this.remove(var2);
         }

         this.add(var1);

         for(int var6 = 0; var6 < var4.size(); ++var6) {
            this.add((MenuItem)var4.elementAt(var6));
         }

      }
   }

   public void insert(String var1, int var2) {
      this.insert(new MenuItem(var1), var2);
   }

   public void addSeparator() {
      this.add("-");
   }

   public void insertSeparator(int var1) {
      if (var1 < 0) {
         throw new IllegalArgumentException("index less than zero.");
      } else {
         int var2 = this.getItemCount();
         Vector var3 = new Vector();

         for(int var4 = var1; var4 < var2; ++var4) {
            var3.addElement(this.getItem(var1));
            this.remove(var1);
         }

         this.addSeparator();

         for(int var5 = 0; var5 < var3.size(); ++var5) {
            this.add((MenuItem)var3.elementAt(var5));
         }

      }
   }

   public synchronized void remove(int var1) {
      MenuItem var2 = this.getItem(var1);
      this.items.removeElementAt(var1);
      MenuPeer var3 = (MenuPeer)super.peer;
      if (var3 != null) {
         ((MenuComponent)var2).removeNotify();
         var2.parent = null;
         var3.delItem(var1);
      }

   }

   public synchronized void remove(MenuComponent var1) {
      int var2 = this.items.indexOf(var1);
      if (var2 >= 0) {
         this.remove(var2);
      }

   }

   public synchronized void removeAll() {
      int var1 = this.getItemCount();

      for(int var2 = 0; var2 < var1; ++var2) {
         this.remove(0);
      }

   }

   boolean handleShortcut(KeyEvent var1) {
      int var2 = this.getItemCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         MenuItem var4 = this.getItem(var3);
         if (var4.handleShortcut(var1)) {
            return true;
         }
      }

      return false;
   }

   MenuItem getShortcutMenuItem(MenuShortcut var1) {
      int var2 = this.getItemCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         MenuItem var4 = this.getItem(var3).getShortcutMenuItem(var1);
         if (var4 != null) {
            return var4;
         }
      }

      return null;
   }

   synchronized Enumeration shortcuts() {
      Vector var1 = new Vector();
      int var2 = this.getItemCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         MenuItem var4 = this.getItem(var3);
         if (var4 instanceof Menu) {
            Enumeration var6 = ((Menu)var4).shortcuts();

            while(var6.hasMoreElements()) {
               var1.addElement(var6.nextElement());
            }
         } else {
            MenuShortcut var5 = var4.getShortcut();
            if (var5 != null) {
               var1.addElement(var5);
            }
         }
      }

      return var1.elements();
   }

   void deleteShortcut(MenuShortcut var1) {
      int var2 = this.getItemCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         this.getItem(var3).deleteShortcut();
      }

   }

   private void writeObject(ObjectOutputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultWriteObject();
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      for(int var2 = 0; var2 < this.items.size(); ++var2) {
         MenuItem var3 = (MenuItem)this.items.elementAt(var2);
         var3.parent = this;
      }

   }

   public String paramString() {
      String var1 = ",tearOff=" + this.tearOff + ",isHelpMenu=" + this.isHelpMenu;
      return super.paramString() + var1;
   }
}
