package java.awt;

import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.peer.MenuBarPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Enumeration;
import java.util.Vector;

public class MenuBar extends MenuComponent implements MenuContainer {
   Vector menus = new Vector();
   Menu helpMenu;
   private static final String base = "menubar";
   private static int nameCounter;
   private static final long serialVersionUID = -4930327919388951260L;
   private int menuBarSerializedDataVersion = 1;

   public MenuBar() {
      super.name = "menubar" + nameCounter++;
   }

   public void addNotify() {
      super.peer = Toolkit.getDefaultToolkit().createMenuBar(this);
      int var1 = this.getMenuCount();

      for(int var2 = 0; var2 < var1; ++var2) {
         this.getMenu(var2).addNotify();
      }

   }

   public void removeNotify() {
      int var1 = this.getMenuCount();

      for(int var2 = 0; var2 < var1; ++var2) {
         this.getMenu(var2).removeNotify();
      }

      super.removeNotify();
   }

   public Menu getHelpMenu() {
      return this.helpMenu;
   }

   public synchronized void setHelpMenu(Menu var1) {
      if (this.helpMenu != var1) {
         if (this.helpMenu != null) {
            this.helpMenu.removeNotify();
            this.helpMenu.parent = null;
         }

         if (var1.parent != this) {
            this.add(var1);
         }

         this.helpMenu = var1;
         if (var1 != null) {
            var1.isHelpMenu = true;
            var1.parent = this;
            MenuBarPeer var2 = (MenuBarPeer)super.peer;
            if (var2 != null) {
               if (var1.peer == null) {
                  var1.addNotify();
               }

               var2.addHelpMenu(var1);
            }
         }

      }
   }

   public synchronized Menu add(Menu var1) {
      if (var1.parent != null) {
         var1.parent.remove(var1);
      }

      this.menus.addElement(var1);
      var1.parent = this;
      MenuBarPeer var2 = (MenuBarPeer)super.peer;
      if (var2 != null) {
         if (var1.peer == null) {
            var1.addNotify();
         }

         var2.addMenu(var1);
      }

      return var1;
   }

   public synchronized void remove(int var1) {
      MenuBarPeer var2 = (MenuBarPeer)super.peer;
      if (var2 != null) {
         Menu var3 = this.getMenu(var1);
         var3.removeNotify();
         var3.parent = null;
         var2.delMenu(var1);
      }

      this.menus.removeElementAt(var1);
   }

   public synchronized void remove(MenuComponent var1) {
      int var2 = this.menus.indexOf(var1);
      if (var2 >= 0) {
         this.remove(var2);
      }

   }

   public int getMenuCount() {
      return this.countMenus();
   }

   public int countMenus() {
      return this.menus.size();
   }

   public Menu getMenu(int var1) {
      return (Menu)this.menus.elementAt(var1);
   }

   public synchronized Enumeration shortcuts() {
      Vector var1 = new Vector();
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         Enumeration var4 = this.getMenu(var3).shortcuts();

         while(var4.hasMoreElements()) {
            var1.addElement(var4.nextElement());
         }
      }

      return var1.elements();
   }

   public MenuItem getShortcutMenuItem(MenuShortcut var1) {
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         MenuItem var4 = this.getMenu(var3).getShortcutMenuItem(var1);
         if (var4 != null) {
            return var4;
         }
      }

      return null;
   }

   boolean handleShortcut(KeyEvent var1) {
      int var2 = ((AWTEvent)var1).getID();
      if (var2 != 401 && var2 != 402) {
         return false;
      } else {
         int var3 = Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
         if ((((InputEvent)var1).getModifiers() & var3) == 0) {
            return false;
         } else {
            int var4 = this.getMenuCount();

            for(int var5 = 0; var5 < var4; ++var5) {
               Menu var6 = this.getMenu(var5);
               if (var6.handleShortcut(var1)) {
                  return true;
               }
            }

            return false;
         }
      }
   }

   public void deleteShortcut(MenuShortcut var1) {
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         this.getMenu(var3).deleteShortcut(var1);
      }

   }

   private void writeObject(ObjectOutputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultWriteObject();
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      for(int var2 = 0; var2 < this.menus.size(); ++var2) {
         Menu var3 = (Menu)this.menus.elementAt(var2);
         var3.parent = this;
      }

   }
}
