package java.awt;

import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.awt.peer.ScrollbarPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

public class Scrollbar extends Component implements Adjustable {
   public static final int HORIZONTAL = 0;
   public static final int VERTICAL = 1;
   int value;
   int maximum;
   int minimum;
   int visibleAmount;
   int orientation;
   int lineIncrement;
   int pageIncrement;
   transient AdjustmentListener adjustmentListener;
   private static final String base = "scrollbar";
   private static int nameCounter;
   private static final long serialVersionUID = 8451667562882310543L;
   private int scrollbarSerializedDataVersion;

   public Scrollbar() {
      this(1, 0, 10, 0, 100);
   }

   public Scrollbar(int var1) {
      this(var1, 0, 10, 0, 100);
   }

   public Scrollbar(int var1, int var2, int var3, int var4, int var5) {
      this.lineIncrement = 1;
      this.pageIncrement = 10;
      this.scrollbarSerializedDataVersion = 1;
      super.name = "scrollbar" + nameCounter++;
      switch (var1) {
         case 0:
         case 1:
            this.orientation = var1;
            this.setValues(var2, var3, var4, var5);
            return;
         default:
            throw new IllegalArgumentException("illegal scrollbar orientation");
      }
   }

   public void addNotify() {
      super.peer = ((Component)this).getToolkit().createScrollbar(this);
      super.addNotify();
   }

   public int getOrientation() {
      return this.orientation;
   }

   public synchronized void setOrientation(int var1) {
      if (var1 != this.orientation) {
         switch (var1) {
            case 0:
            case 1:
               this.orientation = var1;
               Object var2 = Component.LOCK;
               synchronized(var2){}

               try {
                  if (super.peer != null) {
                     ((Component)this).removeNotify();
                     this.addNotify();
                     ((Component)this).invalidate();
                  }
               } catch (Throwable var4) {
                  throw var4;
               }

               return;
            default:
               throw new IllegalArgumentException("illegal scrollbar orientation");
         }
      }
   }

   public int getValue() {
      return this.value;
   }

   public synchronized void setValue(int var1) {
      this.setValues(var1, this.visibleAmount, this.minimum, this.maximum);
   }

   public int getMinimum() {
      return this.minimum;
   }

   public synchronized void setMinimum(int var1) {
      this.setValues(this.value, this.visibleAmount, var1, this.maximum);
   }

   public int getMaximum() {
      return this.maximum;
   }

   public synchronized void setMaximum(int var1) {
      this.setValues(this.value, this.visibleAmount, this.minimum, var1);
   }

   public int getVisibleAmount() {
      return this.getVisible();
   }

   public int getVisible() {
      return this.visibleAmount;
   }

   public synchronized void setVisibleAmount(int var1) {
      this.setValues(this.value, var1, this.minimum, this.maximum);
   }

   public synchronized void setUnitIncrement(int var1) {
      this.setLineIncrement(var1);
   }

   public void setLineIncrement(int var1) {
      this.lineIncrement = var1;
      ScrollbarPeer var2 = (ScrollbarPeer)super.peer;
      if (var2 != null) {
         var2.setLineIncrement(var1);
      }

   }

   public int getUnitIncrement() {
      return this.getLineIncrement();
   }

   public int getLineIncrement() {
      return this.lineIncrement;
   }

   public synchronized void setBlockIncrement(int var1) {
      this.setPageIncrement(var1);
   }

   public void setPageIncrement(int var1) {
      this.pageIncrement = var1;
      ScrollbarPeer var2 = (ScrollbarPeer)super.peer;
      if (var2 != null) {
         var2.setPageIncrement(var1);
      }

   }

   public int getBlockIncrement() {
      return this.getPageIncrement();
   }

   public int getPageIncrement() {
      return this.pageIncrement;
   }

   public synchronized void setValues(int var1, int var2, int var3, int var4) {
      if (var4 <= var3) {
         var4 = var3 + 1;
      }

      if (var2 > var4 - var3) {
         var2 = var4 - var3;
      }

      if (var2 < 1) {
         var2 = 1;
      }

      if (var1 < var3) {
         var1 = var3;
      }

      if (var1 > var4 - var2) {
         var1 = var4 - var2;
      }

      this.value = var1;
      this.visibleAmount = var2;
      this.minimum = var3;
      this.maximum = var4;
      ScrollbarPeer var5 = (ScrollbarPeer)super.peer;
      if (var5 != null) {
         var5.setValues(var1, this.visibleAmount, var3, var4);
      }

   }

   public synchronized void addAdjustmentListener(AdjustmentListener var1) {
      this.adjustmentListener = AWTEventMulticaster.add(this.adjustmentListener, var1);
      super.newEventsOnly = true;
   }

   public synchronized void removeAdjustmentListener(AdjustmentListener var1) {
      this.adjustmentListener = AWTEventMulticaster.remove(this.adjustmentListener, var1);
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 601) {
         return (super.eventMask & 256L) != 0L || this.adjustmentListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof AdjustmentEvent) {
         this.processAdjustmentEvent((AdjustmentEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processAdjustmentEvent(AdjustmentEvent var1) {
      if (this.adjustmentListener != null) {
         this.adjustmentListener.adjustmentValueChanged(var1);
      }

   }

   protected String paramString() {
      return super.paramString() + ",val=" + this.value + ",vis=" + this.visibleAmount + ",min=" + this.minimum + ",max=" + this.maximum + (this.orientation == 1 ? ",vert" : ",horz");
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "adjustmentL", this.adjustmentListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while((var2 = var1.readObject()) != null) {
         String var3 = ((String)var2).intern();
         if (var3 == "adjustmentL") {
            this.addAdjustmentListener((AdjustmentListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }
}
