package java.awt;

import java.awt.peer.TextAreaPeer;

public class TextArea extends TextComponent {
   int rows;
   int columns;
   private static final String base = "text";
   private static int nameCounter;
   public static final int SCROLLBARS_BOTH = 0;
   public static final int SCROLLBARS_VERTICAL_ONLY = 1;
   public static final int SCROLLBARS_HORIZONTAL_ONLY = 2;
   public static final int SCROLLBARS_NONE = 3;
   private int scrollbarVisibility;
   private static final long serialVersionUID = 3692302836626095722L;

   public TextArea() {
      this("", 0, 0, 0);
   }

   public TextArea(String var1) {
      this(var1, 0, 0, 0);
   }

   public TextArea(int var1, int var2) {
      this("", var1, var2);
   }

   public TextArea(String var1, int var2, int var3) {
      this(var1, var2, var3, 0);
   }

   public TextArea(String var1, int var2, int var3, int var4) {
      super(var1);
      super.name = "text" + nameCounter++;
      this.rows = var2;
      this.columns = var3;
      this.scrollbarVisibility = var4;
   }

   public void addNotify() {
      super.peer = ((Component)this).getToolkit().createTextArea(this);
      super.addNotify();
   }

   public synchronized void insert(String var1, int var2) {
      this.insertText(var1, var2);
   }

   public void insertText(String var1, int var2) {
      TextAreaPeer var3 = (TextAreaPeer)super.peer;
      if (var3 != null) {
         var3.insertText(var1, var2);
      } else {
         super.text = super.text.substring(0, var2) + var1 + super.text.substring(var2);
      }
   }

   public synchronized void append(String var1) {
      this.appendText(var1);
   }

   public void appendText(String var1) {
      if (super.peer != null) {
         this.insertText(var1, ((TextComponent)this).getText().length());
      } else {
         super.text = super.text + var1;
      }
   }

   public synchronized void replaceRange(String var1, int var2, int var3) {
      this.replaceText(var1, var2, var3);
   }

   public void replaceText(String var1, int var2, int var3) {
      TextAreaPeer var4 = (TextAreaPeer)super.peer;
      if (var4 != null) {
         var4.replaceText(var1, var2, var3);
      } else {
         super.text = super.text.substring(0, var2) + var1 + super.text.substring(var3);
      }
   }

   public int getRows() {
      return this.rows;
   }

   public void setRows(int var1) {
      int var2 = this.rows;
      if (var1 < 0) {
         throw new IllegalArgumentException("rows less than zero.");
      } else {
         if (var1 != var2) {
            this.rows = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public int getColumns() {
      return this.columns;
   }

   public void setColumns(int var1) {
      int var2 = this.columns;
      if (var1 < 0) {
         throw new IllegalArgumentException("columns less than zero.");
      } else {
         if (var1 != var2) {
            this.columns = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public int getScrollbarVisibility() {
      return this.scrollbarVisibility;
   }

   public Dimension getPreferredSize(int var1, int var2) {
      return this.preferredSize(var1, var2);
   }

   public Dimension preferredSize(int var1, int var2) {
      Object var4 = Component.LOCK;
      synchronized(var4){}

      Dimension var3;
      try {
         TextAreaPeer var6 = (TextAreaPeer)super.peer;
         var3 = var6 != null ? var6.preferredSize(var1, var2) : super.preferredSize();
      } catch (Throwable var8) {
         throw var8;
      }

      return var3;
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      Dimension var1;
      try {
         var1 = this.rows > 0 && this.columns > 0 ? this.preferredSize(this.rows, this.columns) : super.preferredSize();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   public Dimension getMinimumSize(int var1, int var2) {
      return this.minimumSize(var1, var2);
   }

   public Dimension minimumSize(int var1, int var2) {
      Object var4 = Component.LOCK;
      synchronized(var4){}

      Dimension var3;
      try {
         TextAreaPeer var6 = (TextAreaPeer)super.peer;
         var3 = var6 != null ? var6.minimumSize(var1, var2) : super.minimumSize();
      } catch (Throwable var8) {
         throw var8;
      }

      return var3;
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Object var2 = Component.LOCK;
      synchronized(var2){}

      Dimension var1;
      try {
         var1 = this.rows > 0 && this.columns > 0 ? this.minimumSize(this.rows, this.columns) : super.minimumSize();
      } catch (Throwable var5) {
         throw var5;
      }

      return var1;
   }

   protected String paramString() {
      String var1;
      switch (this.scrollbarVisibility) {
         case 0:
            var1 = "both";
            break;
         case 1:
            var1 = "vertical-only";
            break;
         case 2:
            var1 = "horizontal-only";
            break;
         case 3:
            var1 = "none";
            break;
         default:
            var1 = "invalid display policy";
      }

      return super.paramString() + ",rows=" + this.rows + ",columns=" + this.columns + ", scrollbarVisibility=" + var1;
   }
}
