package java.awt;

import java.awt.datatransfer.Clipboard;
import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ButtonPeer;
import java.awt.peer.CanvasPeer;
import java.awt.peer.CheckboxMenuItemPeer;
import java.awt.peer.CheckboxPeer;
import java.awt.peer.ChoicePeer;
import java.awt.peer.DialogPeer;
import java.awt.peer.FileDialogPeer;
import java.awt.peer.FontPeer;
import java.awt.peer.FramePeer;
import java.awt.peer.LabelPeer;
import java.awt.peer.LightweightPeer;
import java.awt.peer.ListPeer;
import java.awt.peer.MenuBarPeer;
import java.awt.peer.MenuItemPeer;
import java.awt.peer.MenuPeer;
import java.awt.peer.PanelPeer;
import java.awt.peer.PopupMenuPeer;
import java.awt.peer.ScrollPanePeer;
import java.awt.peer.ScrollbarPeer;
import java.awt.peer.TextAreaPeer;
import java.awt.peer.TextFieldPeer;
import java.awt.peer.WindowPeer;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.net.URL;
import java.util.Properties;

public abstract class Toolkit {
   private static Toolkit toolkit;
   private static Properties properties;

   protected abstract ButtonPeer createButton(Button var1);

   protected abstract TextFieldPeer createTextField(TextField var1);

   protected abstract LabelPeer createLabel(Label var1);

   protected abstract ListPeer createList(List var1);

   protected abstract CheckboxPeer createCheckbox(Checkbox var1);

   protected abstract ScrollbarPeer createScrollbar(Scrollbar var1);

   protected abstract ScrollPanePeer createScrollPane(ScrollPane var1);

   protected abstract TextAreaPeer createTextArea(TextArea var1);

   protected abstract ChoicePeer createChoice(Choice var1);

   protected abstract FramePeer createFrame(Frame var1);

   protected abstract CanvasPeer createCanvas(Canvas var1);

   protected abstract PanelPeer createPanel(Panel var1);

   protected abstract WindowPeer createWindow(Window var1);

   protected abstract DialogPeer createDialog(Dialog var1);

   protected abstract MenuBarPeer createMenuBar(MenuBar var1);

   protected abstract MenuPeer createMenu(Menu var1);

   protected abstract PopupMenuPeer createPopupMenu(PopupMenu var1);

   protected abstract MenuItemPeer createMenuItem(MenuItem var1);

   protected abstract FileDialogPeer createFileDialog(FileDialog var1);

   protected abstract CheckboxMenuItemPeer createCheckboxMenuItem(CheckboxMenuItem var1);

   protected LightweightPeer createComponent(Component var1) {
      return new java.awt.LightweightPeer(var1);
   }

   protected abstract FontPeer getFontPeer(String var1, int var2);

   protected void loadSystemColors(int[] var1) {
   }

   public abstract Dimension getScreenSize();

   public abstract int getScreenResolution();

   public abstract ColorModel getColorModel();

   public abstract String[] getFontList();

   public abstract FontMetrics getFontMetrics(Font var1);

   public abstract void sync();

   public static synchronized Toolkit getDefaultToolkit() {
      if (toolkit == null) {
         String var0 = System.getProperty("awt.toolkit", "sun.awt.motif.MToolkit");

         try {
            toolkit = (Toolkit)Class.forName(var0).newInstance();
         } catch (ClassNotFoundException var1) {
            throw new AWTError("Toolkit not found: " + var0);
         } catch (InstantiationException var2) {
            throw new AWTError("Could not instantiate Toolkit: " + var0);
         } catch (IllegalAccessException var3) {
            throw new AWTError("Could not access Toolkit: " + var0);
         }
      }

      return toolkit;
   }

   public abstract Image getImage(String var1);

   public abstract Image getImage(URL var1);

   public abstract boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract int checkImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract Image createImage(ImageProducer var1);

   public Image createImage(byte[] var1) {
      return this.createImage(var1, 0, var1.length);
   }

   public abstract Image createImage(byte[] var1, int var2, int var3);

   public abstract PrintJob getPrintJob(Frame var1, String var2, Properties var3);

   public abstract void beep();

   public abstract Clipboard getSystemClipboard();

   public int getMenuShortcutKeyMask() {
      return 2;
   }

   protected static Container getNativeContainer(Component var0) {
      return var0.getNativeContainer();
   }

   public static String getProperty(String var0, String var1) {
      String var2 = properties.getProperty(var0);
      return var2 == null ? var1 : var2;
   }

   public final EventQueue getSystemEventQueue() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkAwtEventQueueAccess();
      }

      return this.getSystemEventQueueImpl();
   }

   protected abstract EventQueue getSystemEventQueueImpl();

   static EventQueue getEventQueue() {
      return toolkit.getSystemEventQueueImpl();
   }

   static {
      String var0 = File.separator;
      File var1 = new File(System.getProperty("java.home") + var0 + "lib" + var0 + "awt.properties");
      properties = new Properties();

      try {
         FileInputStream var2 = new FileInputStream(var1);
         properties.load(new BufferedInputStream(var2));
         var2.close();
      } catch (Exception var3) {
      }
   }
}
