package java.awt;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.peer.CheckboxPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

public class Checkbox extends Component implements ItemSelectable {
   String label;
   boolean state;
   CheckboxGroup group;
   transient ItemListener itemListener;
   private static final String base = "checkbox";
   private static int nameCounter;
   private static final long serialVersionUID = 7270714317450821763L;
   private int checkboxSerializedDataVersion;

   synchronized void setStateInternal(boolean var1) {
      this.state = var1;
      CheckboxPeer var2 = (CheckboxPeer)super.peer;
      if (var2 != null) {
         var2.setState(var1);
      }

   }

   public Checkbox() {
      this("", false, (CheckboxGroup)null);
   }

   public Checkbox(String var1) {
      this(var1, false, (CheckboxGroup)null);
   }

   public Checkbox(String var1, boolean var2) {
      this(var1, var2, (CheckboxGroup)null);
   }

   public Checkbox(String var1, boolean var2, CheckboxGroup var3) {
      this.checkboxSerializedDataVersion = 1;
      super.name = "checkbox" + nameCounter++;
      this.label = var1;
      this.state = var2;
      this.group = var3;
      if (var2 && var3 != null) {
         var3.setSelectedCheckbox(this);
      }

   }

   public Checkbox(String var1, CheckboxGroup var2, boolean var3) {
      this(var1, var3, var2);
   }

   public void addNotify() {
      super.peer = ((Component)this).getToolkit().createCheckbox(this);
      super.addNotify();
   }

   public String getLabel() {
      return this.label;
   }

   public synchronized void setLabel(String var1) {
      this.label = var1;
      CheckboxPeer var2 = (CheckboxPeer)super.peer;
      if (var2 != null) {
         var2.setLabel(var1);
      }

   }

   public boolean getState() {
      return this.state;
   }

   public void setState(boolean var1) {
      CheckboxGroup var2 = this.group;
      if (var2 != null) {
         if (var1) {
            var2.setSelectedCheckbox(this);
         } else if (var2.getSelectedCheckbox() == this) {
            var1 = true;
         }
      }

      this.setStateInternal(var1);
   }

   public Object[] getSelectedObjects() {
      if (this.state) {
         Object[] var1 = new Object[]{this.label};
         return var1;
      } else {
         return null;
      }
   }

   public CheckboxGroup getCheckboxGroup() {
      return this.group;
   }

   public void setCheckboxGroup(CheckboxGroup var1) {
      CheckboxGroup var2 = this.group;
      if (var2 != null) {
         var2.setSelectedCheckbox((Checkbox)null);
      }

      synchronized(this){}

      try {
         this.group = var1;
         CheckboxPeer var5 = (CheckboxPeer)super.peer;
         if (var5 != null) {
            var5.setCheckboxGroup(var1);
         }
      } catch (Throwable var7) {
         throw var7;
      }

   }

   public synchronized void addItemListener(ItemListener var1) {
      this.itemListener = AWTEventMulticaster.add(this.itemListener, var1);
      super.newEventsOnly = true;
   }

   public synchronized void removeItemListener(ItemListener var1) {
      this.itemListener = AWTEventMulticaster.remove(this.itemListener, var1);
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 701) {
         return (super.eventMask & 512L) != 0L || this.itemListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ItemEvent) {
         this.processItemEvent((ItemEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processItemEvent(ItemEvent var1) {
      if (this.itemListener != null) {
         this.itemListener.itemStateChanged(var1);
      }

   }

   protected String paramString() {
      String var1 = super.paramString();
      String var2 = this.label;
      if (var2 != null) {
         var1 = var1 + ",label=" + var2;
      }

      return var1 + ",state=" + this.state;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "itemL", this.itemListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while((var2 = var1.readObject()) != null) {
         String var3 = ((String)var2).intern();
         if (var3 == "itemL") {
            this.addItemListener((ItemListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }
}
