package java.awt;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.peer.CheckboxMenuItemPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

public class CheckboxMenuItem extends MenuItem implements ItemSelectable {
   boolean state;
   transient ItemListener itemListener;
   private static final String base = "chkmenuitem";
   private static int nameCounter;
   private static final long serialVersionUID = 6190621106981774043L;
   private int checkboxMenuItemSerializedDataVersion;

   public CheckboxMenuItem() {
      this("", false);
   }

   public CheckboxMenuItem(String var1) {
      this(var1, false);
   }

   public CheckboxMenuItem(String var1, boolean var2) {
      super(var1);
      this.state = false;
      this.checkboxMenuItemSerializedDataVersion = 1;
      super.name = "chkmenuitem" + nameCounter++;
      this.state = var2;
   }

   public void addNotify() {
      super.peer = Toolkit.getDefaultToolkit().createCheckboxMenuItem(this);
      super.addNotify();
   }

   public boolean getState() {
      return this.state;
   }

   public synchronized void setState(boolean var1) {
      this.state = var1;
      CheckboxMenuItemPeer var2 = (CheckboxMenuItemPeer)super.peer;
      if (var2 != null) {
         var2.setState(var1);
      }

   }

   public synchronized Object[] getSelectedObjects() {
      if (this.state) {
         Object[] var1 = new Object[]{super.label};
         return var1;
      } else {
         return null;
      }
   }

   public synchronized void addItemListener(ItemListener var1) {
      this.itemListener = AWTEventMulticaster.add(this.itemListener, var1);
      super.newEventsOnly = true;
   }

   public synchronized void removeItemListener(ItemListener var1) {
      this.itemListener = AWTEventMulticaster.remove(this.itemListener, var1);
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 701) {
         return (super.eventMask & 512L) != 0L || this.itemListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ItemEvent) {
         this.processItemEvent((ItemEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processItemEvent(ItemEvent var1) {
      if (this.itemListener != null) {
         this.itemListener.itemStateChanged(var1);
      }

   }

   public String paramString() {
      return super.paramString() + ",state=" + this.state;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "itemL", this.itemListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while((var2 = var1.readObject()) != null) {
         String var3 = ((String)var2).intern();
         if (var3 == "itemL") {
            this.addItemListener((ItemListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }
}
